==> google-cloud-service-management-1.2.2.tar.gz: google-cloud-service-management-1.2.2/google/cloud/servicemanagement_v1/services/service_manager/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

from google.api import service_pb2  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
import pkg_resources

from google.cloud.servicemanagement_v1.types import resources, servicemanager

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-service-management",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class ServiceManagerTransport(abc.ABC):
    """Abstract transport class for ServiceManager."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/cloud-platform.read-only",
        "https://www.googleapis.com/auth/service.management",
        "https://www.googleapis.com/auth/service.management.readonly",
    )

    DEFAULT_HOST: str = "servicemanagement.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_services: gapic_v1.method.wrap_method(
                self.list_services,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service: gapic_v1.method.wrap_method(
                self.get_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service: gapic_v1.method.wrap_method(
                self.create_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_service: gapic_v1.method.wrap_method(
                self.delete_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.undelete_service: gapic_v1.method.wrap_method(
                self.undelete_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_service_configs: gapic_v1.method.wrap_method(
                self.list_service_configs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service_config: gapic_v1.method.wrap_method(
                self.get_service_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service_config: gapic_v1.method.wrap_method(
                self.create_service_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.submit_config_source: gapic_v1.method.wrap_method(
                self.submit_config_source,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_service_rollouts: gapic_v1.method.wrap_method(
                self.list_service_rollouts,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service_rollout: gapic_v1.method.wrap_method(
                self.get_service_rollout,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service_rollout: gapic_v1.method.wrap_method(
                self.create_service_rollout,
                default_timeout=None,
                client_info=client_info,
            ),
            self.generate_config_report: gapic_v1.method.wrap_method(
                self.generate_config_report,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_services(
        self,
    ) -> Callable[
        [servicemanager.ListServicesRequest],
        Union[
            servicemanager.ListServicesResponse,
            Awaitable[servicemanager.ListServicesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service(
        self,
    ) -> Callable[
        [servicemanager.GetServiceRequest],
        Union[resources.ManagedService, Awaitable[resources.ManagedService]],
    ]:
        raise NotImplementedError()

    @property
    def create_service(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_service(
        self,
    ) -> Callable[
        [servicemanager.DeleteServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def undelete_service(
        self,
    ) -> Callable[
        [servicemanager.UndeleteServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_service_configs(
        self,
    ) -> Callable[
        [servicemanager.ListServiceConfigsRequest],
        Union[
            servicemanager.ListServiceConfigsResponse,
            Awaitable[servicemanager.ListServiceConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service_config(
        self,
    ) -> Callable[
        [servicemanager.GetServiceConfigRequest],
        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_config(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceConfigRequest],
        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
    ]:
        raise NotImplementedError()

    @property
    def submit_config_source(
        self,
    ) -> Callable[
        [servicemanager.SubmitConfigSourceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_service_rollouts(
        self,
    ) -> Callable[
        [servicemanager.ListServiceRolloutsRequest],
        Union[
            servicemanager.ListServiceRolloutsResponse,
            Awaitable[servicemanager.ListServiceRolloutsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service_rollout(
        self,
    ) -> Callable[
        [servicemanager.GetServiceRolloutRequest],
        Union[resources.Rollout, Awaitable[resources.Rollout]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_rollout(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceRolloutRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def generate_config_report(
        self,
    ) -> Callable[
        [servicemanager.GenerateConfigReportRequest],
        Union[
            servicemanager.GenerateConfigReportResponse,
            Awaitable[servicemanager.GenerateConfigReportResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ServiceManagerTransport",)

==> google-cloud-service-management-1.3.0.tar.gz: google-cloud-service-management-1.3.0/google/cloud/servicemanagement_v1/services/service_manager/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

from google.api import service_pb2  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
import pkg_resources

from google.cloud.servicemanagement_v1.types import resources, servicemanager

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-service-management",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class ServiceManagerTransport(abc.ABC):
    """Abstract transport class for ServiceManager."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/cloud-platform.read-only",
        "https://www.googleapis.com/auth/service.management",
        "https://www.googleapis.com/auth/service.management.readonly",
    )

    DEFAULT_HOST: str = "servicemanagement.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_services: gapic_v1.method.wrap_method(
                self.list_services,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service: gapic_v1.method.wrap_method(
                self.get_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service: gapic_v1.method.wrap_method(
                self.create_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_service: gapic_v1.method.wrap_method(
                self.delete_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.undelete_service: gapic_v1.method.wrap_method(
                self.undelete_service,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_service_configs: gapic_v1.method.wrap_method(
                self.list_service_configs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service_config: gapic_v1.method.wrap_method(
                self.get_service_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service_config: gapic_v1.method.wrap_method(
                self.create_service_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.submit_config_source: gapic_v1.method.wrap_method(
                self.submit_config_source,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_service_rollouts: gapic_v1.method.wrap_method(
                self.list_service_rollouts,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_service_rollout: gapic_v1.method.wrap_method(
                self.get_service_rollout,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_service_rollout: gapic_v1.method.wrap_method(
                self.create_service_rollout,
                default_timeout=None,
                client_info=client_info,
            ),
            self.generate_config_report: gapic_v1.method.wrap_method(
                self.generate_config_report,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_services(
        self,
    ) -> Callable[
        [servicemanager.ListServicesRequest],
        Union[
            servicemanager.ListServicesResponse,
            Awaitable[servicemanager.ListServicesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service(
        self,
    ) -> Callable[
        [servicemanager.GetServiceRequest],
        Union[resources.ManagedService, Awaitable[resources.ManagedService]],
    ]:
        raise NotImplementedError()

    @property
    def create_service(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_service(
        self,
    ) -> Callable[
        [servicemanager.DeleteServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def undelete_service(
        self,
    ) -> Callable[
        [servicemanager.UndeleteServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_service_configs(
        self,
    ) -> Callable[
        [servicemanager.ListServiceConfigsRequest],
        Union[
            servicemanager.ListServiceConfigsResponse,
            Awaitable[servicemanager.ListServiceConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service_config(
        self,
    ) -> Callable[
        [servicemanager.GetServiceConfigRequest],
        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_config(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceConfigRequest],
        Union[service_pb2.Service, Awaitable[service_pb2.Service]],
    ]:
        raise NotImplementedError()

    @property
    def submit_config_source(
        self,
    ) -> Callable[
        [servicemanager.SubmitConfigSourceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_service_rollouts(
        self,
    ) -> Callable[
        [servicemanager.ListServiceRolloutsRequest],
        Union[
            servicemanager.ListServiceRolloutsResponse,
            Awaitable[servicemanager.ListServiceRolloutsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_service_rollout(
        self,
    ) -> Callable[
        [servicemanager.GetServiceRolloutRequest],
        Union[resources.Rollout, Awaitable[resources.Rollout]],
    ]:
        raise NotImplementedError()

    @property
    def create_service_rollout(
        self,
    ) -> Callable[
        [servicemanager.CreateServiceRolloutRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def generate_config_report(
        self,
    ) -> Callable[
        [servicemanager.GenerateConfigReportRequest],
        Union[
            servicemanager.GenerateConfigReportResponse,
            Awaitable[servicemanager.GenerateConfigReportResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ServiceManagerTransport",)
